Get the children labels from a pif_class
children.RdGets the labels of the pif elements that make up a pif_global_ensemble_class.

pif_classchildren.RdGets the labels of the pif elements that make up a pif_global_ensemble_class.